'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
const stream = require("stream");
const assert = require("assert");
exports.pt = function (pre, $options) {
    const options = $options || {};
    assert(typeof pre === 'string', `prepend-transform usage error -> first argument must be a string.`);
    assert(typeof options === 'object', `prepend-transform usage error -> 'options' value must be an object.`);
    let lastLineData = '';
    return new stream.Transform({
        objectMode: true,
        transform(chunk, encoding, cb) {
            let data = String(chunk);
            if (lastLineData) {
                data = lastLineData + data;
            }
            let lines = data.split('\n');
            lastLineData = lines.splice(lines.length - 1, 1)[0];
            if (options.omitWhitespace) {
                lines.forEach(l => {
                    if (/[^ ]/.test(l)) {
                        this.push(pre + l + '\n');
                    }
                });
            }
            else {
                lines.forEach(l => {
                    this.push(pre + l + '\n');
                });
            }
            cb();
        },
        flush(cb) {
            if (lastLineData) {
                if (options.omitWhitespace && /[^ ]/.test(lastLineData)) {
                    this.push(pre + lastLineData + '\n');
                }
                else {
                    this.push(pre + lastLineData + '\n');
                }
            }
            lastLineData = '';
            cb();
        }
    });
};
exports.default = exports.pt;
